@@ -17,11 +17,8 @@ Copyright 2013 Python Charmers Pty Ltd, Australia.
 The software is distributed under an MIT licence. See LICENSE.txt.
 """
 
-import os
+import sys
 
 from libfuturize.main import main
 
-# We use os._exit() because sys.exit() seems to interact badly with
-# subprocess.check_output() ...
-os._exit(main())
-
+sys.exit(main())
